import React from "react";
import { View, Text, Button, TextInput } from "react-native";

export class LoginForm extends React.Component {
  constructor(props) {
    super(props);

    this.state = {
      errorMsg: "",
      username: "",
      password: ""
    };
  }

  handleError = error => {
    this.setState({ errorMsg: error });
  };

  // show/hide this form
  handleView = e => {
    this.props.toggleView(this.props.view);
  };

  handleLogin = e => {
    const name = this.state.username;
    const password = this.state.password;
    e.preventDefault();

    // Send login info to the server
    fetch(`http://172.20.2.110:5000/user/login`, {
      method: "POST",
      headers: {
        Accept: "application/json",
        "Content-Type": "application/json"
      },
      body: JSON.stringify({
        name: name,
        password: password
      })
    })
      .then(res => res.json())
      .then(
        result => {
          if (result.name) {
            this.props.handleState(result);
            this.handleView();
          } else {
            this.handleError(result.message);
          }
        },
        // Note: it's important to handle errors here
        // instead of a catch() block so that we don't swallow
        // exceptions from actual bugs in components.
        error => {
          console.log(error);
        }
      );
  };

  render() {
    return (
      <View className="fade-main">
        <View className="sticky">
          <Text
            id="closeLoginFormX"
            className="close"
            onPress={this.handleView}
          >
            ×
          </Text>
        </View>
        <View className="login">
          <Text>Login</Text>
          <TextInput
            placeholder="Enter Username"
            value={this.state.username}
            onChangeText={username => this.setState({ username })}
            id="loginUsernameInput"
            autoFocus
            required
          />
          <TextInput
            placeholder="Enter password"
            secureTextEntry={true}
            value={this.state.password}
            onChangeText={password => this.setState({ password })}
            id="loginPasswordInput"
            required
          />
          <Button
            id="submitLoginButton"
            type="submit"
            title="Submit"
            onPress={this.handleLogin}
          />
          <Text>{this.state.errorMsg}</Text>
        </View>
      </View>
    );
  }
}

export default LoginForm;
